==> alloy-ui-3.0.1.jar: META-INF/resources/webjars/alloy-ui/3.0.1/src/aui-base/HISTORY.md <==
# AUI Base

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-base).

## @VERSION@

* [AUI-1653](https://issues.liferay.com/browse/AUI-1653) Clean up wrong A.Lang.isNode calls

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1576](https://issues.liferay.com/browse/AUI-1576) A.Lang.String.Uncamelize method drops letters from the string
* [AUI-1577](https://issues.liferay.com/browse/AUI-1577) Inconsistent string truncation in aui-base-lang
* [AUI-1527](https://issues.liferay.com/browse/AUI-1527) Add base keyboard navigation
* [AUI-1309](https://issues.liferay.com/browse/AUI-1309) Make aui-scheduler responsive
* [AUI-1535](https://issues.liferay.com/browse/AUI-1535) _unescapeHTML errors when string contains a hash, but is not an HTML entity
* [AUI-991](https://issues.liferay.com/browse/AUI-991) Add ability to interact with audio/video player
* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1303](https://issues.liferay.com/browse/AUI-1303) Make aui-form-builder responsive
* [AUI-1332](https://issues.liferay.com/browse/AUI-1332) Decouple property list panel from diagram builder
* [AUI-1383](https://issues.liferay.com/browse/AUI-1383) Decouple datatable subcomponents
* [AUI-1339](https://issues.liferay.com/browse/AUI-1339) Escape form builder parameters
* [AUI-1340](https://issues.liferay.com/browse/AUI-1340) Escape data table parameters
* [AUI-1328](https://issues.liferay.com/browse/AUI-1328) Move automated tasks from Grunt to Gulp
* [AUI-1388](https://issues.liferay.com/browse/AUI-1388) Make aui-toggler responsive
* [AUI-1310](https://issues.liferay.com/browse/AUI-1310) Make aui-tooltip responsive
* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1299](https://issues.liferay.com/browse/AUI-1299) Make aui-carousel responsive
* [AUI-1335](https://issues.liferay.com/browse/AUI-1335) Tooltips should make HTML escaped by default
* [AUI-1173](https://issues.liferay.com/browse/AUI-1173) Single page application utility
* [AUI-1290](https://issues.liferay.com/browse/AUI-1290) TimePicker dependency 'autocomplete-list' may render 'autocomplete' unsuable
* [AUI-1153](https://issues.liferay.com/browse/AUI-1153) Create Bootstrap's Dropdown module
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1145](https://issues.liferay.com/browse/AUI-1145) Create Bootstrap's Alert module
* [AUI-1150](https://issues.liferay.com/browse/AUI-1150) Create Bootstrap's Affix module
* [AUI-1255](https://issues.liferay.com/browse/AUI-1255) Apply "display: none" on Tooltip hide
* [AUI-1151](https://issues.liferay.com/browse/AUI-1151) Create Bootstrap's ScrollSpy module
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1236](https://issues.liferay.com/browse/AUI-1236) Add .table class to DataTable on Bootstrap 3
* [AUI-1252](https://issues.liferay.com/browse/AUI-1252) Fix cursors on dynamic generated tabs
* [AUI-1225](https://issues.liferay.com/browse/AUI-1225) Import Bootstrap 3 into a new module and remove Grunt bootstrap task

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1104](https://issues.liferay.com/browse/AUI-1104) Add Undo/Redo module
* [AUI-1173](https://issues.liferay.com/browse/AUI-1173) Single page application utility
* [AUI-1217](https://issues.liferay.com/browse/AUI-1217) Fix bugs on YUI v3.15.0 migration
* [AUI-1180](https://issues.liferay.com/browse/AUI-1180) Format files generated by Shifter
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants

==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-base/HISTORY.md <==
# AUI Base

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-base).

## @VERSION@

No registries yet.

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

* [AUI-1758](https://issues.liferay.com/browse/AUI-1758) LayoutBuilder should allow all breakpoints and should not have a min width
* [AUI-1653](https://issues.liferay.com/browse/AUI-1653) Clean up wrong A.Lang.isNode calls

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1576](https://issues.liferay.com/browse/AUI-1576) A.Lang.String.Uncamelize method drops letters from the string
* [AUI-1577](https://issues.liferay.com/browse/AUI-1577) Inconsistent string truncation in aui-base-lang
* [AUI-1527](https://issues.liferay.com/browse/AUI-1527) Add base keyboard navigation
* [AUI-1309](https://issues.liferay.com/browse/AUI-1309) Make aui-scheduler responsive
* [AUI-1535](https://issues.liferay.com/browse/AUI-1535) _unescapeHTML errors when string contains a hash, but is not an HTML entity
* [AUI-991](https://issues.liferay.com/browse/AUI-991) Add ability to interact with audio/video player
* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1303](https://issues.liferay.com/browse/AUI-1303) Make aui-form-builder responsive
* [AUI-1332](https://issues.liferay.com/browse/AUI-1332) Decouple property list panel from diagram builder
* [AUI-1383](https://issues.liferay.com/browse/AUI-1383) Decouple datatable subcomponents
* [AUI-1339](https://issues.liferay.com/browse/AUI-1339) Escape form builder parameters
* [AUI-1340](https://issues.liferay.com/browse/AUI-1340) Escape data table parameters
* [AUI-1328](https://issues.liferay.com/browse/AUI-1328) Move automated tasks from Grunt to Gulp
* [AUI-1388](https://issues.liferay.com/browse/AUI-1388) Make aui-toggler responsive
* [AUI-1310](https://issues.liferay.com/browse/AUI-1310) Make aui-tooltip responsive
* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1299](https://issues.liferay.com/browse/AUI-1299) Make aui-carousel responsive
* [AUI-1335](https://issues.liferay.com/browse/AUI-1335) Tooltips should make HTML escaped by default
* [AUI-1173](https://issues.liferay.com/browse/AUI-1173) Single page application utility
* [AUI-1290](https://issues.liferay.com/browse/AUI-1290) TimePicker dependency 'autocomplete-list' may render 'autocomplete' unsuable
* [AUI-1153](https://issues.liferay.com/browse/AUI-1153) Create Bootstrap's Dropdown module
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1145](https://issues.liferay.com/browse/AUI-1145) Create Bootstrap's Alert module
* [AUI-1150](https://issues.liferay.com/browse/AUI-1150) Create Bootstrap's Affix module
* [AUI-1255](https://issues.liferay.com/browse/AUI-1255) Apply "display: none" on Tooltip hide
* [AUI-1151](https://issues.liferay.com/browse/AUI-1151) Create Bootstrap's ScrollSpy module
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1236](https://issues.liferay.com/browse/AUI-1236) Add .table class to DataTable on Bootstrap 3
* [AUI-1252](https://issues.liferay.com/browse/AUI-1252) Fix cursors on dynamic generated tabs
* [AUI-1225](https://issues.liferay.com/browse/AUI-1225) Import Bootstrap 3 into a new module and remove Grunt bootstrap task

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1104](https://issues.liferay.com/browse/AUI-1104) Add Undo/Redo module
* [AUI-1173](https://issues.liferay.com/browse/AUI-1173) Single page application utility
* [AUI-1217](https://issues.liferay.com/browse/AUI-1217) Fix bugs on YUI v3.15.0 migration
* [AUI-1180](https://issues.liferay.com/browse/AUI-1180) Format files generated by Shifter
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
